"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.promiseTry = exports.proxyGetters = void 0;
/**
 * Proxies getters on the target to the object.
 *
 * @param  {Object} target
 * The proxy to add getters to.
 *
 * @param  {Object} obj
 * Object with properties we want to proxy getters to.
 *
 * @params {string[]} keys
 * The keys to proxy.
 */
function proxyGetters(target, obj, keys) {
    keys.forEach((key) => {
        Object.defineProperty(target, key, {
            get: () => obj[key],
        });
    });
}
exports.proxyGetters = proxyGetters;
/**
 * Invokes the function in a promise-safe way.
 */
function promiseTry(fn) {
    return new Promise((resolve, reject) => {
        try {
            resolve(fn());
        }
        catch (err) {
            reject(err);
        }
    });
}
exports.promiseTry = promiseTry;
//# sourceMappingURL=utils.js.map